@@ -83,7 +83,7 @@ import org.apache.activemq.util.LongSequenceGenerator;
 
 import static org.apache.activemq.artemis.core.protocol.openwire.util.OpenWireUtil.SELECTOR_AWARE_OPTION;
 
-public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, OpenWireInterceptor, OpenWireConnection, OpenWireRedirectHandler> implements ClusterTopologyListener {
+public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, OpenWireInterceptor, OpenWireConnection, OpenWireRoutingHandler> implements ClusterTopologyListener {
 
    private static final List<String> websocketRegistryNames = Collections.EMPTY_LIST;
 
@@ -143,7 +143,7 @@ public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, O
    private final List<OpenWireInterceptor> incomingInterceptors = new ArrayList<>();
    private final List<OpenWireInterceptor> outgoingInterceptors = new ArrayList<>();
 
-   private final OpenWireRedirectHandler redirectHandler;
+   private final OpenWireRoutingHandler routingHandler;
 
    protected static class VirtualTopicConfig {
       public int filterPathTerminus;
@@ -195,7 +195,7 @@ public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, O
       //make sure we don't cluster advisories
       clusterManager.addProtocolIgnoredAddress(AdvisorySupport.ADVISORY_TOPIC_PREFIX);
 
-      redirectHandler = new OpenWireRedirectHandler(server, this);
+      routingHandler = new OpenWireRoutingHandler(server, this);
    }
 
    /** Is Duplicate detection enabled when used with failover clients. */
@@ -336,10 +336,6 @@ public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, O
       return entry;
    }
 
-   @Override
-   public void removeHandler(String name) {
-   }
-
    @Override
    public void handleBuffer(RemotingConnection connection, ActiveMQBuffer buffer) {
    }
@@ -685,8 +681,8 @@ public class OpenWireProtocolManager  extends AbstractProtocolManager<Command, O
    }
 
    @Override
-   public OpenWireRedirectHandler getRedirectHandler() {
-      return redirectHandler;
+   public OpenWireRoutingHandler getRoutingHandler() {
+      return routingHandler;
    }
 
    @Override
